@@ -10,9 +10,9 @@ class CClickFilter : public CInputFilter {
 
   virtual void HandleEvent(Dasher::CEvent * pEvent);
 
-  virtual void DecorateView(CDasherView *pView);
-  virtual void Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel);
-  virtual void KeyDown(int iTime, int iId, CDasherModel *pModel);
+  virtual bool DecorateView(CDasherView *pView);
+  virtual bool Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel, Dasher::VECTOR_SYMBOL_PROB *pAdded, int *pNumDeleted);
+  virtual void KeyDown(int iTime, int iId, CDasherModel *pModel, CUserLogBase *pUserLog);
  
  private:
   CDasherView *pDasherView;
