@@ -64,25 +64,36 @@ static char THIS_FILE[] = __FILE__;
 #endif
 #endif
 
-CDasherInterfaceBase::CDasherInterfaceBase()
-                  :m_Alphabet(0), m_pDasherModel(0), m_DasherScreen(0),
-		   m_pDasherView(0), m_pInput(0), m_AlphIO(0), m_ColourIO(0), m_pUserLog(NULL),
-		   m_pInputFilter(NULL) {
-
+CDasherInterfaceBase::CDasherInterfaceBase() {
+  // Ensure that pointers to 'owned' objects are set to NULL.
+  m_Alphabet = 0;
+  m_pDasherModel = 0;
+  m_DasherScreen = 0;
+  m_pDasherView = 0;
+  m_pInput = 0;
+  m_AlphIO = 0;
+  m_ColourIO = 0;
+  m_pUserLog = 0;
+  m_pInputFilter = 0;
   m_pNCManager = 0;
-  
-  m_bGlobalLock = false;
-  m_bShutdownLock = false;
-  m_bRecreateLock = false;
 
+  // Various state variables
   m_bRedrawScheduled = false;
+  
+  m_iCurrentState = ST_START;
+  
+  m_iLockCount = 0;
+  m_bGlobalLock = false;
 
-  m_pEventHandler = new CEventHandler(this);
- 
+  // TODO: Are these actually needed?
   strCurrentContext = ". ";
-
   strTrainfileBuffer = "";
 
+  // Create an event handler.
+  m_pEventHandler = new CEventHandler(this);
+
+  m_bLastChanged = true;
+
   // Global logging object we can use from anywhere
   g_pLogger = new CFileLogger("dasher.log",
                               g_iLogLevel,
@@ -122,21 +133,29 @@ void CDasherInterfaceBase::Realize() {
     m_pUserLog = new CUserLog(m_pEventHandler, m_pSettingsStore, iUserLogLevel, m_Alphabet);  
 
   CreateFactories();
+  CreateLocalFactories();
+
+  CreateInput();
   CreateInputFilter();
   SetupActionButtons();
 
   // FIXME - need to rationalise this sort of thing.
-  InvalidateContext(true);
+  // InvalidateContext(true);
   ScheduleRedraw();
     
   // All the setup is done by now, so let the user log object know
   // that future parameter changes should be logged.
   if (m_pUserLog != NULL) 
     m_pUserLog->InitIsDone();
+
+  // TODO: Make things work when model is created latet
+  ChangeState(TR_MODEL_INIT);
 }
 
 CDasherInterfaceBase::~CDasherInterfaceBase() {
 
+  DASHER_ASSERT(m_iCurrentState == ST_SHUTDOWN);
+
   delete m_pDasherModel;        // The order of some of these deletions matters
   delete m_Alphabet;
   delete m_pDasherView;
@@ -232,7 +251,7 @@ void CDasherInterfaceBase::InterfaceEventHandler(Dasher::CEvent *pEvent) {
 	 SetStringParameter(SP_COLOUR_ID, GetStringParameter(SP_DEFAULT_COLOUR_ID));
       break;
     case LP_LANGUAGE_MODEL_ID:
-      CreateDasherModel();
+      CreateNCManager();
       break;
     case LP_LINE_WIDTH:
       ScheduleRedraw();
@@ -247,6 +266,9 @@ void CDasherInterfaceBase::InterfaceEventHandler(Dasher::CEvent *pEvent) {
       CreateInputFilter();
       ScheduleRedraw();
       break;
+    case BP_DASHER_PAUSED:
+      ScheduleRedraw();
+      break;
     default:
       break;
     }
@@ -280,8 +302,18 @@ void CDasherInterfaceBase::InterfaceEventHandler(Dasher::CEvent *pEvent) {
     }
   }
   else if(pEvent->m_iEventType == EV_LOCK) {
-    // TODO: 'Reference counting' for locks?
     CLockEvent *pLockEvent(static_cast<CLockEvent *>(pEvent));
+
+//     // TODO: Sort this out - at the moment these don't occur in pairs, so the old boolean variable is still needed
+//     if(pLockEvent->m_bLock) {
+//       if(m_bGlobalLock)
+// 	AddLock(0);
+//     }
+//     else {
+//       if(!m_bGlobalLock)
+// 	ReleaseLock(0);
+//     }
+    
     m_bGlobalLock = pLockEvent->m_bLock;
   }
 }
@@ -297,24 +329,50 @@ void CDasherInterfaceBase::WriteTrainFilePartial() {
   strTrainfileBuffer = strTrainfileBuffer.substr(100);
 }
 
-void CDasherInterfaceBase::CreateDasherModel() 
-{
+void CDasherInterfaceBase::CreateModel(int iOffset) {
+  // Creating a model without a node creation manager is a bad plan
+  if(!m_pNCManager)
+    return;
+
+  if(m_pDasherModel) {
+    delete m_pDasherModel;
+    m_pDasherModel = 0;
+  }
+  
+  if(m_deGameModeStrings.size() == 0) {
+    m_pDasherModel = new CDasherModel(m_pEventHandler, m_pSettingsStore, m_pNCManager, this, m_pDasherView, iOffset);
+  }
+  else {
+    m_pDasherModel = new CDasherModel(m_pEventHandler, m_pSettingsStore, m_pNCManager, this, m_pDasherView, iOffset, true, m_deGameModeStrings[0]);
+  }
+}
+
+void CDasherInterfaceBase::CreateNCManager() {
+  // TODO: Try and make this work without necessarilty rebuilding the model
+
   if(!m_AlphIO)
     return;
 
-  // TODO: Move training into model?
-  // TODO: Do we really need to check for a valid language model?
   int lmID = GetLongParameter(LP_LANGUAGE_MODEL_ID);
-  if( lmID != -1 ) {
 
-    // Train the new language model
+  if( lmID == -1 ) 
+    return;
+
+ // Train the new language model
     CLockEvent *pEvent;
     
     pEvent = new CLockEvent("Training Dasher", true, 0);
     m_pEventHandler->InsertEvent(pEvent);
     delete pEvent;
 
-    m_bRecreateLock = true;
+    AddLock(0);
+
+    int iOffset;
+
+    if(m_pDasherModel)
+      iOffset = m_pDasherModel->GetOffset();
+    else
+      iOffset = 0; // TODO: Is this right?
 
     // Delete the old model and create a new one
     if(m_pDasherModel) {
@@ -328,13 +386,10 @@ void CDasherInterfaceBase::CreateDasherModel()
     }
       
     if(m_deGameModeStrings.size() == 0) {
-      m_pNCManager = new CNodeCreationManager(m_pEventHandler, m_pSettingsStore, false, "", m_AlphIO);
-      m_pDasherModel = new CDasherModel(m_pEventHandler, m_pSettingsStore, m_pNCManager, this);
+      m_pNCManager = new CNodeCreationManager(this, m_pEventHandler, m_pSettingsStore, false, "", m_AlphIO);
     }
     else {
-      m_pNCManager = new CNodeCreationManager(m_pEventHandler, m_pSettingsStore, true, m_deGameModeStrings[0], m_AlphIO);
-      m_pDasherModel = new CDasherModel(m_pEventHandler, m_pSettingsStore, m_pNCManager, this, true, m_deGameModeStrings[0]);
-      //      m_deGameModeStrings.pop_front();
+      m_pNCManager = new CNodeCreationManager(this, m_pEventHandler, m_pSettingsStore, true, m_deGameModeStrings[0], m_AlphIO);
     }
 
     m_Alphabet = m_pNCManager->GetAlphabet();
@@ -358,34 +413,35 @@ void CDasherInterfaceBase::CreateDasherModel()
     pEvent = new CLockEvent("Training Dasher", false, 0);
     m_pEventHandler->InsertEvent(pEvent);
     delete pEvent;
-  }
 
-  Start();
-  Redraw(true);
+    ReleaseLock(0);
 
-  m_bRecreateLock = false;
+    // TODO: Eventually we'll not have to pass the NC manager to the model...
+    CreateModel(iOffset);
 }
 
-void CDasherInterfaceBase::Start() {
-  // TODO: Clarify the relationship between Start() and
-  // InvalidateContext() - I believe that they essentially do the same
-  // thing
-  PauseAt(0, 0);
-  if(m_pDasherModel != 0) {
-    m_pDasherModel->Start();
-  }
-  if(m_pDasherView != 0) {
-//     m_pDasherView->ResetSum();
-//     m_pDasherView->ResetSumCounter();
-//     m_pDasherView->ResetYAutoOffset();
-  }
+// void CDasherInterfaceBase::Start() {
+//   // TODO: Clarify the relationship between Start() and
+//   // InvalidateContext() - I believe that they essentially do the same
+//   // thing
+//   PauseAt(0, 0);
+//   if(m_pDasherModel != 0) {
+//     m_pDasherModel->Start();
+//   }
+//   if(m_pDasherView != 0) {
+// //     m_pDasherView->ResetSum();
+// //     m_pDasherView->ResetSumCounter();
+// //     m_pDasherView->ResetYAutoOffset();
+//   }
 
-  int iMinWidth;
+// TODO: Reimplement this sometime
+
+//   int iMinWidth;
   
-  if(m_pInputFilter && m_pInputFilter->GetMinWidth(iMinWidth)) {
-    m_pDasherModel->LimitRoot(iMinWidth);
-  }
-}
+//   if(m_pInputFilter && m_pInputFilter->GetMinWidth(iMinWidth)) {
+//     m_pDasherModel->LimitRoot(iMinWidth);
+//   }
+// }
 
 void CDasherInterfaceBase::PauseAt(int MouseX, int MouseY) {
   SetBoolParameter(BP_DASHER_PAUSED, true);
@@ -403,12 +459,6 @@ void CDasherInterfaceBase::PauseAt(int MouseX, int MouseY) {
 void CDasherInterfaceBase::Halt() {
   SetBoolParameter(BP_DASHER_PAUSED, true);
 
-  // Obsolete?
-  if(GetBoolParameter(BP_MOUSEPOS_MODE)) {
-    SetLongParameter(LP_MOUSE_POS_BOX, 1);
-  }
-  //
-
   // This will cause us to reinitialise the frame rate counter - ie we start off slowly
   if(m_pDasherModel != 0)
     m_pDasherModel->Halt();
@@ -417,14 +467,8 @@ void CDasherInterfaceBase::Halt() {
 void CDasherInterfaceBase::Unpause(unsigned long Time) {
   SetBoolParameter(BP_DASHER_PAUSED, false);
 
-  if(m_pDasherModel != 0) {
+  if(m_pDasherModel != 0) 
     m_pDasherModel->Reset_framerate(Time);
-    //m_pDasherModel->Set_paused(m_Paused);
-  }
-  if(m_pDasherView != 0) {
-//     m_pDasherView->ResetSum();
-//     m_pDasherView->ResetSumCounter();
-  }
 
   Dasher::CStartEvent oEvent;
   m_pEventHandler->InsertEvent(&oEvent);
@@ -453,7 +497,7 @@ void CDasherInterfaceBase::CreateInput() {
 
 void CDasherInterfaceBase::NewFrame(unsigned long iTime, bool bForceRedraw) {
   // Fail if Dasher is locked
-  if(m_bGlobalLock || m_bShutdownLock || m_bRecreateLock)
+  if(m_iCurrentState != ST_NORMAL)
     return;
 
   bool bChanged(false);
@@ -485,7 +529,15 @@ void CDasherInterfaceBase::NewFrame(unsigned long iTime, bool bForceRedraw) {
     }
   }
 
-  Redraw(bChanged || m_bRedrawScheduled || bForceRedraw);
+  // TODO: This is a bit hacky - we really need to sort out the redraw logic
+  if((!bChanged && m_bLastChanged) || m_bRedrawScheduled || bForceRedraw) {
+    m_pDasherView->Screen()->SetCaptureBackground(true);
+    m_pDasherView->Screen()->SetLoadBackground(true);
+  }
+
+  Redraw((bChanged || m_bLastChanged) || m_bRedrawScheduled || bForceRedraw);
+
+  m_bLastChanged = bChanged;
   m_bRedrawScheduled = false;
 
   // This just passes the time through to the framerate tracker, so we
@@ -506,6 +558,7 @@ void CDasherInterfaceBase::CheckRedraw() {
 /// otherwise we're wasting effort.
 
 void CDasherInterfaceBase::Redraw(bool bRedrawNodes) {
+
   if(!m_pDasherView || !m_pDasherModel)
     return;
   
@@ -550,17 +603,7 @@ void CDasherInterfaceBase::ChangeAlphabet() {
 
   SetBoolParameter( BP_TRAINING, true );
 
-//   m_AlphInfo = m_AlphIO->GetInfo(NewAlphabetID);
-
-//   //AlphabetID = m_AlphInfo.AlphID.c_str();
-
-//   //  std::auto_ptr < CAlphabet > ptrOld(m_Alphabet);       // So we can delete the old alphabet later
-
-//   m_Alphabet = new CAlphabet(m_AlphInfo);
-
-  delete m_pDasherModel;
-  m_pDasherModel = 0;
-  CreateDasherModel();
+  CreateNCManager();
 
   // Let our user log object know about the new alphabet since
   // it needs to convert symbols into text for the log file.
@@ -610,10 +653,6 @@ void CDasherInterfaceBase::ChangeView() {
   }
 }
 
-void CDasherInterfaceBase::GetAlphabets(std::vector <std::string >*AlphabetList) {
-  m_AlphIO->GetAlphabets(AlphabetList);
-}
-
 const CAlphIO::AlphInfo & CDasherInterfaceBase::GetInfo(const std::string &AlphID) {
   return m_AlphIO->GetInfo(AlphID);
 }
@@ -626,10 +665,6 @@ void CDasherInterfaceBase::DeleteAlphabet(const std::string &AlphID) {
   m_AlphIO->Delete(AlphID);
 }
 
-void CDasherInterfaceBase::GetColours(std::vector <std::string >*ColourList) {
-  m_ColourIO->GetColours(ColourList);
-}
-
 /*
 	I've used C style I/O because I found that C++ style I/O bloated
 	the Win32 code enormously. The overhead of loading the buffer into
@@ -644,6 +679,8 @@ int CDasherInterfaceBase::TrainFile(string Filename, int iTotalBytes, int iOffse
   if((InputFile = fopen(Filename.c_str(), "r")) == (FILE *) 0)
     return 0;
 
+  AddLock(0);
+
   const int BufferSize = 1024;
   char InputBuffer[BufferSize];
   string StringBuffer;
@@ -652,7 +689,7 @@ int CDasherInterfaceBase::TrainFile(string Filename, int iTotalBytes, int iOffse
 
   vector < symbol > Symbols;
 
-  CAlphabetManagerFactory::CTrainer * pTrainer = m_pDasherModel->GetTrainer();
+  CAlphabetManagerFactory::CTrainer * pTrainer = m_pNCManager->GetTrainer();
   do {
     NumberRead = fread(InputBuffer, 1, BufferSize - 1, InputFile);
     InputBuffer[NumberRead] = '\0';
@@ -679,6 +716,8 @@ int CDasherInterfaceBase::TrainFile(string Filename, int iTotalBytes, int iOffse
 
   fclose(InputFile);
 
+  ReleaseLock(0);
+
   return iTotalRead;
 }
 
@@ -724,58 +763,71 @@ void CDasherInterfaceBase::ResetNats() {
 }
 
 
-void CDasherInterfaceBase::InvalidateContext(bool bForceStart) {
-  m_pDasherModel->m_strContextBuffer = "";
+// TODO: Check that none of this needs to be reimplemented
 
-  Dasher::CEditContextEvent oEvent(10);
+// void CDasherInterfaceBase::InvalidateContext(bool bForceStart) {
+//   m_pDasherModel->m_strContextBuffer = "";
+
+//   Dasher::CEditContextEvent oEvent(10);
+//   m_pEventHandler->InsertEvent(&oEvent);
+
+//    std::string strNewContext(m_pDasherModel->m_strContextBuffer);
+
+//   // We keep track of an internal context and compare that to what
+//   // we are given - don't restart Dasher if nothing has changed.
+//   // This should really be integrated with DasherModel, which
+//   // probably will be the case when we start to deal with being able
+//   // to back off indefinitely. For now though we'll keep it in a
+//   // separate string.
+
+//    int iContextLength( 6 ); // The 'important' context length - should really get from language model
+
+//    // FIXME - use unicode lengths
+
+//    if(bForceStart || (strNewContext.substr( std::max(static_cast<int>(strNewContext.size()) - iContextLength, 0)) != strCurrentContext.substr( std::max(static_cast<int>(strCurrentContext.size()) - iContextLength, 0)))) {
+
+//      if(m_pDasherModel != NULL) {
+//        // TODO: Reimplement this
+//        //       if(m_pDasherModel->m_bContextSensitive || bForceStart) {
+//        {
+//  	m_pDasherModel->SetContext(strNewContext);
+//  	PauseAt(0,0);
+//        }
+//      }
+    
+//      strCurrentContext = strNewContext;
+//      WriteTrainFileFull();
+//    }
+
+//    if(bForceStart) {
+//      int iMinWidth;
+
+//      if(m_pInputFilter && m_pInputFilter->GetMinWidth(iMinWidth)) {
+//        m_pDasherModel->LimitRoot(iMinWidth);
+//      }
+//    }
+
+//    if(m_pDasherView)
+//      while( m_pDasherModel->CheckForNewRoot(m_pDasherView) ) {
+//        // Do nothing
+//      }
+
+//    ScheduleRedraw();
+// }
+
+// TODO: Fix this
+
+std::string CDasherInterfaceBase::GetContext(int iStart, int iLength) {
+  m_strContext = "";
+  
+  CEditContextEvent oEvent(iStart, iLength);
   m_pEventHandler->InsertEvent(&oEvent);
 
-   std::string strNewContext(m_pDasherModel->m_strContextBuffer);
-
-  // We keep track of an internal context and compare that to what
-  // we are given - don't restart Dasher if nothing has changed.
-  // This should really be integrated with DasherModel, which
-  // probably will be the case when we start to deal with being able
-  // to back off indefinitely. For now though we'll keep it in a
-  // separate string.
-
-   int iContextLength( 6 ); // The 'important' context length - should really get from language model
-
-   // FIXME - use unicode lengths
-
-   if(bForceStart || (strNewContext.substr( std::max(static_cast<int>(strNewContext.size()) - iContextLength, 0)) != strCurrentContext.substr( std::max(static_cast<int>(strCurrentContext.size()) - iContextLength, 0)))) {
-
-     if(m_pDasherModel != NULL) {
-       // TODO: Reimplement this
-       //       if(m_pDasherModel->m_bContextSensitive || bForceStart) {
-       {
- 	m_pDasherModel->SetContext(strNewContext);
- 	PauseAt(0,0);
-       }
-     }
-    
-     strCurrentContext = strNewContext;
-     WriteTrainFileFull();
-   }
-
-   if(bForceStart) {
-     int iMinWidth;
-
-     if(m_pInputFilter && m_pInputFilter->GetMinWidth(iMinWidth)) {
-       m_pDasherModel->LimitRoot(iMinWidth);
-     }
-   }
-
-   if(m_pDasherView)
-     while( m_pDasherModel->CheckForNewRoot(m_pDasherView) ) {
-       // Do nothing
-     }
-
-   ScheduleRedraw();
+  return m_strContext;
 }
 
 void CDasherInterfaceBase::SetContext(std::string strNewContext) {
-  m_pDasherModel->m_strContextBuffer = strNewContext;
+  m_strContext = strNewContext;
 }
 
 // Control mode stuff
@@ -827,21 +879,29 @@ CUserLogBase* CDasherInterfaceBase::GetUserLogPtr() {
 }
 
 void CDasherInterfaceBase::KeyDown(int iTime, int iId) {
-  if(m_bGlobalLock || m_bShutdownLock || m_bRecreateLock)
+  if(m_iCurrentState != ST_NORMAL)
     return;
 
   if(m_pInputFilter && !GetBoolParameter(BP_TRAINING)) {
     m_pInputFilter->KeyDown(iTime, iId, m_pDasherModel, m_pUserLog);
   }
+
+  if(m_pInput && !GetBoolParameter(BP_TRAINING)) {
+    m_pInput->KeyDown(iTime, iId);
+  }
 }
 
 void CDasherInterfaceBase::KeyUp(int iTime, int iId) {
-  if(m_bGlobalLock || m_bShutdownLock || m_bRecreateLock)
+  if(m_iCurrentState != ST_NORMAL)
     return;
 
   if(m_pInputFilter && !GetBoolParameter(BP_TRAINING)) {
     m_pInputFilter->KeyUp(iTime, iId, m_pDasherModel);
   }
+
+  if(m_pInput && !GetBoolParameter(BP_TRAINING)) {
+    m_pInput->KeyUp(iTime, iId);
+  }
 }
 
 void CDasherInterfaceBase::CreateInputFilter()
@@ -899,10 +959,12 @@ void CDasherInterfaceBase::GetPermittedValues(int iParameter, std::vector<std::s
   // TODO: Deprecate direct calls to these functions
   switch (iParameter) {
   case SP_ALPHABET_ID:
-    GetAlphabets(&vList);
+    if(m_AlphIO)
+      m_AlphIO->GetAlphabets(&vList);
     break;
   case SP_COLOUR_ID:
-    GetColours(&vList);
+    if(m_ColourIO)
+      m_ColourIO->GetColours(&vList);
     break;
   case SP_INPUT_FILTER:
     m_oModuleManager.ListModules(1, vList);
@@ -914,7 +976,7 @@ void CDasherInterfaceBase::GetPermittedValues(int iParameter, std::vector<std::s
 }
 
 void CDasherInterfaceBase::StartShutdown() {
-  m_bShutdownLock = true;
+  ChangeState(TR_SHUTDOWN);
 }
 
 bool CDasherInterfaceBase::GetModuleSettings(const std::string &strName, SModuleSettings **pSettings, int *iCount) {
@@ -1029,6 +1091,82 @@ int CDasherInterfaceBase::GetRenderCount() {
     return 0;
 }
 
- void CDasherInterfaceBase::AddActionButton(const std::string &strName) {
+void CDasherInterfaceBase::AddActionButton(const std::string &strName) {
   m_vRightButtons.push_back(new CActionButton(this, strName, false));
- }
+}
+
+
+void CDasherInterfaceBase::OnUIRealised() {
+  StartTimer();
+  ChangeState(TR_UI_INIT);
+}
+
+
+void CDasherInterfaceBase::ChangeState(ETransition iTransition) {
+  static EState iTransitionTable[ST_NUM][TR_NUM] = {
+    {ST_MODEL, ST_UI, ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN},
+    {ST_FORBIDDEN, ST_NORMAL, ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN},
+    {ST_NORMAL, ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN},
+    {ST_FORBIDDEN, ST_FORBIDDEN, ST_LOCKED, ST_FORBIDDEN, ST_SHUTDOWN},
+    {ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN, ST_NORMAL, ST_FORBIDDEN},
+    {ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN, ST_FORBIDDEN}
+  };
+
+  EState iNewState(iTransitionTable[m_iCurrentState][iTransition]);
+
+  if(iNewState != ST_FORBIDDEN) {
+    LeaveState(m_iCurrentState);
+    EnterState(iNewState);
+
+    m_iCurrentState = iNewState;
+  }
+}
+
+void CDasherInterfaceBase::LeaveState(EState iState) {
+
+}
+
+void CDasherInterfaceBase::EnterState(EState iState) {
+  switch(iState) {
+  case ST_SHUTDOWN:
+    ShutdownTimer();  
+    WriteTrainFileFull();
+    break;
+  default:
+    // Not handled
+    break;
+  }
+}
+
+void CDasherInterfaceBase::AddLock(int iLockFlags) {
+  if(m_iLockCount == 0)
+    ChangeState(TR_LOCK);
+
+  ++m_iLockCount;
+}
+
+void CDasherInterfaceBase::ReleaseLock(int iLockFlags) {
+  if(m_iLockCount > 0)
+    --m_iLockCount;
+
+  if(m_iLockCount == 0)
+    ChangeState(TR_UNLOCK);
+}
+
+void CDasherInterfaceBase::SetBuffer(int iOffset) { 
+  CreateModel(iOffset);
+}
+
+void CDasherInterfaceBase::UnsetBuffer() {
+  // TODO: Write training file?
+  if(m_pDasherModel)
+    delete m_pDasherModel;
+
+  m_pDasherModel = 0;
+}
+
+void CDasherInterfaceBase::SetOffset(int iOffset) {
+  if(m_pDasherModel)
+    m_pDasherModel->SetOffset(iOffset, m_pDasherView);
+}
+
