@@ -6,6 +6,7 @@
 #define __DasherScreen_h_
 
 #include "DasherTypes.h"
+#include "../DasherCore/ColourIO.h"
 
 // DJW20050505 - renamed DrawText to DrawString - windows defines DrawText as a macro and it's 
 // really hard to work around
@@ -14,9 +15,10 @@
 namespace Dasher {
   class CDasherScreen;
   class CDasherInterfaceBase;
-  class CCustomColours;
 }
 
+
+
 class Dasher::CDasherScreen
 {
 public:
@@ -77,7 +79,7 @@ public:
 
   virtual void DrawRectangle(screenint x1, screenint y1, screenint x2, screenint y2, int Color, int iOutlineColour, Opts::ColorSchemes ColorScheme, bool bDrawOutline, bool bFill, int iThickness) = 0;
 
-  virtual void DrawCircle(screenint iCX, screenint iCY, screenint iR, int iColour, bool bFill) = 0;
+  virtual void DrawCircle(screenint iCX, screenint iCY, screenint iR, int iColour, int iFillColour, int iThickness, bool bFill) = 0;
 
   // Draw a line of fixed colour (usually black). Intended for static UI elements such as a cross-hair
   //! Draw a line between each of the points in the array
@@ -125,8 +127,11 @@ public:
   //! Set a colour scheme
   //!
   //! \param ColourScheme A colour scheme that should be used
-  virtual void SetColourScheme(const CCustomColours * ColourScheme) = 0;
-
+  virtual void SetColourScheme(const Dasher::CColourIO::ColourInfo *pColourScheme) = 0;
+  
+  virtual void SetLoadBackground (bool value)=0;
+  virtual void SetCaptureBackground (bool value)=0;
+  
 protected:
   //! Width and height of the screen
   const screenint m_iWidth, m_iHeight;
