@@ -3,8 +3,8 @@
 
 #include "DasherView.h"
 #include "DasherModel.h"
-
 #include "DasherModule.h"
+#include "UserLogBase.h"
 
 namespace Dasher {
   class CDasherInterfaceBase;
@@ -19,9 +19,16 @@ class CInputFilter : public CDasherModule {
 
   virtual void HandleEvent(Dasher::CEvent * pEvent) {};
   virtual bool DecorateView(CDasherView *pView) { return false; };
-  virtual void KeyDown(int Time, int iId, CDasherModel *pModel) {};
+  virtual void KeyDown(int Time, int iId, CDasherModel *pModel, CUserLogBase *pUserLog) {};
   virtual void KeyUp(int Time, int iId, CDasherModel *pModel) {};
-  virtual void Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {};
+  virtual bool Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel, Dasher::VECTOR_SYMBOL_PROB *pAdded, int *pNumDeleted) { return false; };
+
+  virtual void Activate() {};
+  virtual void Deactivate() {};
+
+  virtual bool GetMinWidth(int &iMinWidth) {
+    return false;
+  }
   
  protected:
   CDasherInterfaceBase *m_pInterface;
