@@ -1,15 +1,12 @@
 #ifndef __gtkdashercontrol_h__
 #define __gtkdashercontrol_h__
 
+#include <gtk/gtk.h>
+
 #include "../Common/ModuleSettings.h"
 #include "Parameters.h"
 #include "ControlManager.h"
 
-#include <gtk/gtk.h>
-#include <gdk/gdk.h>
-
-#include <glib.h>
-
 typedef struct _DasherLockInfo DasherLockInfo;
 
 struct _DasherLockInfo {
@@ -33,12 +30,6 @@ G_BEGIN_DECLS
 #define IS_GTK_DASHER_CONTROL(obj)		(GTK_CHECK_TYPE ((obj), TYPE_GTK_DASHER_CONTROL))
 #define IS_GTK_DASHER_CONTROL_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), TYPE_GTK_DASHER_CONTROL))
 
-// CJB -- shorter access to parameters.
-#define getLong(x) gtk_dasher_control_get_parameter_long( GTK_DASHER_CONTROL(pDasherWidget), x )
-#define getBool(x) gtk_dasher_control_get_parameter_bool( GTK_DASHER_CONTROL(pDasherWidget), x )
-#define getString(x) gtk_dasher_control_get_parameter_string( GTK_DASHER_CONTROL(pDasherWidget), x )
-
-
 typedef struct _GtkDasherControl GtkDasherControl;
 typedef struct _GtkDasherControlClass GtkDasherControlClass;
 
@@ -62,7 +53,7 @@ struct _GtkDasherControlClass {
   void (*dasher_control) (GtkDasherControl * pDasherControl, gint iEvent, gpointer data);
   gboolean (*key_press_event) (GtkDasherControl *pDasherControl, GdkEventKey *pEvent, gpointer data);
   gboolean (*key_release_event) (GtkDasherControl *pDasherControl, GdkEventKey *pEvent, gpointer data);
-  void (*dasher_context_request) (GtkDasherControl * pDasherControl, gint iParameter, gpointer data);
+  void (*dasher_context_request) (GtkDasherControl * pDasherControl, gint iOffset, gint iLength, gpointer data);
   void (*dasher_request_settings) (GtkDasherControl * pDasherControl, gpointer data);
   void (*dasher_lock) (GtkDasherControl * pDasherControl, gpointer pLockInfo, gpointer data);
   void (*dasher_message) (GtkDasherControl * pDasherControl, gpointer pLockInfo, gpointer data);
@@ -85,7 +76,10 @@ const char *gtk_dasher_control_get_parameter_string(GtkDasherControl * pControl,
 GArray *gtk_dasher_control_get_allowed_values(GtkDasherControl * pControl, int iParameter);
 void gtk_dasher_control_train(GtkDasherControl * pControl, const gchar * szFilename);
 void gtk_dasher_control_set_context(GtkDasherControl *pControl, const gchar *szContext);
-void gtk_dasher_control_invalidate_context(GtkDasherControl *pControl, bool bForceStart);
+//void gtk_dasher_control_invalidate_context(GtkDasherControl *pControl, bool bForceStart);
+void gtk_dasher_control_set_buffer(GtkDasherControl *pControl, int iOffset);
+void gtk_dasher_control_set_offset(GtkDasherControl *pControl, int iOffset);
+void gtk_dasher_control_unset_buffer(GtkDasherControl *pControl);
 void gtk_dasher_control_register_node(GtkDasherControl *pControl, int iID, const gchar *szLabel, int iColour);
 void gtk_dasher_control_connect_node(GtkDasherControl *pControl, int iChild, int iParent, int iAfter);
 void gtk_dasher_control_disconnect_node(GtkDasherControl *pControl, int iChild, int iParent);
