@@ -8,11 +8,6 @@
 #define IS_IDASHER_BUFFER_SET(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), IDASHER_BUFFER_SET_TYPE))
 #define IDASHER_BUFFER_SET_GET_INTERFACE(inst) (G_TYPE_INSTANCE_GET_INTERFACE((inst), IDASHER_BUFFER_SET_TYPE, IDasherBufferSetInterface))
 
-enum {
-  CONTEXT_CHANGED,
-  NUM_SIGNALS
-};
-
 // Basic cursor movement commands
 
 enum {
@@ -37,23 +32,25 @@ struct _IDasherBufferSetInterface {
 
   void (*insert_text)(IDasherBufferSet *pSelf, const gchar *szText);
   void (*delete_text)(IDasherBufferSet *pSelf, gint iLength);
-  gchar *(*get_context)(IDasherBufferSet *pSelf, gint iMaxLength);
+  gchar *(*get_context)(IDasherBufferSet *pSelf, gint iOffset, gint iLength);
   void (*edit_move)(IDasherBufferSet *pSelf, gint iDirection, gint iDist);
   void (*edit_delete)(IDasherBufferSet *pSelf, gint iDirection, gint iDist);
   void (*edit_convert)(IDasherBufferSet *pSelf);
   void (*edit_protect)(IDasherBufferSet *pSelf);
   void (*conversion_mode)(IDasherBufferSet *pSelf, gboolean bMode);
+  gint (*get_offset)(IDasherBufferSet *pSelf);
 };
 
 GType idasher_buffer_set_get_type();
 
 void idasher_buffer_set_insert(IDasherBufferSet *pSelf, const gchar *szText);
 void idasher_buffer_set_delete(IDasherBufferSet *pSelf, gint iLength);
-gchar *idasher_buffer_set_get_context(IDasherBufferSet *pSelf, gint iMaxLength);
+gchar *idasher_buffer_set_get_context(IDasherBufferSet *pSelf, gint iOffset, gint iLength);
 void idasher_buffer_set_edit_move(IDasherBufferSet *pSelf, gint iDirection, gint iDist);
 void idasher_buffer_set_edit_delete(IDasherBufferSet *pSelf, gint iDirection, gint iDist);
 void idasher_buffer_set_edit_convert(IDasherBufferSet *pSelf);
 void idasher_buffer_set_edit_protect(IDasherBufferSet *pSelf);
 void idasher_buffer_set_conversion_mode(IDasherBufferSet *pSelf, gboolean bMode);
+gint idasher_buffer_set_get_offset(IDasherBufferSet *pSelf);
 
 #endif
