@@ -35,7 +35,7 @@ static menuentry menutable[] = {
   {BP_PALETTE_CHANGE, IDC_COLOURSCHEME, true}
 };
 
-CAlphabetBox::CAlphabetBox(HWND Parent, CDasherInterface *DI)
+CAlphabetBox::CAlphabetBox(HWND Parent, CDasherInterfaceBase *DI)
 :m_pDasherInterface(DI), m_CurrentAlphabet(DI->GetStringParameter(SP_ALPHABET_ID)), m_CurrentColours(DI->GetStringParameter(SP_COLOUR_ID)), Editing(false), Cloning(false), EditChar(false), CustomBox(0), CurrentGroup(0), CurrentChar(0) {
   m_hwnd = 0;
   m_hPropertySheet = 0;
@@ -47,7 +47,7 @@ void CAlphabetBox::PopulateList() {
 
   m_CurrentAlphabet = m_pDasherInterface->GetStringParameter(SP_ALPHABET_ID);
 
-  m_pDasherInterface->GetAlphabets(&AlphabetList);
+  m_pDasherInterface->GetPermittedValues(SP_ALPHABET_ID, AlphabetList);
 
   int iDefaultIndex(-1);
   int iFallbackIndex(-1);
@@ -84,7 +84,7 @@ void CAlphabetBox::PopulateList() {
   SendMessage(m_hwnd, WM_COMMAND, MAKEWPARAM(IDC_ALPHABETS, LBN_SELCHANGE), 0);
 
   ListBox = GetDlgItem(m_hwnd, IDC_COLOURS);
-  m_pDasherInterface->GetColours(&ColourList);
+  m_pDasherInterface->GetPermittedValues(SP_COLOUR_ID, ColourList);
 
   // Add each string to list box and index each one
   SelectionSet = false;
